@@ -160,7 +160,7 @@ extern int NetOpened;
 
 #ifndef _GPU_API_
 #include "minimal.h"
-#include "gpuAPI/gpuAPI.h"
+
 #include "R3000A.h"
 #include "PsxMem.h"
 #include "PsxHw.h"
@@ -177,6 +177,11 @@ extern int NetOpened;
 #include "Misc.h"
 #include "Debug.h"
 #include "gte.h"
+#if defined(OPENGL_ES) ||  defined(OPENGL_ESM)
+#include "gpu-gles/gpuPlugin.h"
+#else
+#include "gpuAPI/gpuAPI.h"
+#endif
 #endif
 
 
